import React, { useState, useCallback, useEffect } from 'react';
import ReactDOM from 'react-dom';
import { select, axisleft,axisBottom, csv, arc, pie, scaleBand, scaleLinear, max, format} from 'd3';
const csvUrl='https://gist.githubusercontent.com/bindhureddy98/49471f42e5859fe85c4740a85b8b2b43/raw/420a413da16314b8349448b1b3c3d2f59972db72/ice5.csv'
const width=900;
const height=500;
const margin={ top:20,right:50,bottom:40,left:300};
const App=() => {
  const [data,setData]=useState(null);
  useEffect(()=> {
    const row = d => {
      d.population = +d['2019'];
  		return d;
    };
    csv(csvUrl, row).then(data => {
      setData(data.slice(0,10));
    });
  }, []);
  if(!data){
    return <pre>loading......</pre>;
  }
  const innerHeight= height-margin.top-margin.bottom-100;
  const innerWidth=width-margin.left-margin.right;
  
  const yscale=scaleBand()
  	.domain(data.map(d=>d.Country))
  	.range([0,innerHeight]);
  const xscale=scaleLinear()
  	.domain([0, max(data, d=> d.population)])
    .range([0,innerWidth]);
  return (
    <svg width={width} height={height}>
      <g transform={'translate(${margin.left},${margin.top})'}>
        {xScale.ticks().map(tickValue => (
          <g key={tickValue} transform={'translate(${xScale(tickValue)},0)'}>
            <line y2={innerHeight} stroke="blue" />
            <text
              style={{ textAnchor: 'middle'}}
              dy=".70em"
              y={innerHeight+3}
            >
              {tickValue}
            </text>
          </g>
        ))}
        {yScale.domain().map(tickValue=> (
          <text
            key={tickValue}
            style={{ textAnchor: 'end' }}
            x={-3}
            dy=".32em"
            y={yScale(tickValue) + yScale.bandwidth()/2}
          >
            {tickValue}
          </text>
          ))}
        {data.map(d => (
          <rect
            Key={d.Country}
            x={0}
            y={yScale(d.Country)}
            width={xScale(d.population)}
            height={yScale.bandwidth()}
            />
          ))}
      </g>
    </svg>
  );
};
const rootElement=document.getElementById('root');
ReactDOM.render(<App />,rootElement);